@@ -1,8 +1,9 @@
 # coding=utf-8
 
-from tf_geometric.nn.conv.gcn import gcn_cache_normed_edge
+from tf_geometric.nn.conv.gcn import gcn_build_cache_for_graph
 from tf_geometric.nn.conv.appnp import appnp
 import tensorflow as tf
+import warnings
 
 
 class APPNP(tf.keras.Model):
@@ -14,7 +15,7 @@ class APPNP(tf.keras.Model):
         for i, units in enumerate(self.units_list):
             kernel_name = "kernel_{}".format(i)
             kernel = self.add_weight(kernel_name, shape=[last_units, units],
-                                      initializer="glorot_uniform", regularizer=self.kernel_regularizer)
+                                     initializer="glorot_uniform", regularizer=self.kernel_regularizer)
 
             bias_name = "bias_{}".format(i)
             bias = self.add_weight(bias_name, shape=[units],
@@ -61,7 +62,7 @@ class APPNP(tf.keras.Model):
         self.kernels = []
         self.biases = []
 
-    def cache_normed_edge(self, graph, override=False):
+    def build_cache_for_graph(self, graph, override=False):
         """
         Manually compute the normed edge based on this layer's GCN normalization configuration (self.renorm and self.improved) and put it in graph.cache.
         If the normed edge already exists in graph.cache and the override parameter is False, this method will do nothing.
@@ -70,7 +71,24 @@ class APPNP(tf.keras.Model):
         :param override: Whether to override existing cached normed edge.
         :return: None
         """
-        gcn_cache_normed_edge(graph, override=override)
+        gcn_build_cache_for_graph(graph, override=override)
+
+    def cache_normed_edge(self, graph, override=False):
+        """
+        Manually compute the normed edge based on this layer's GCN normalization configuration (self.renorm and self.improved) and put it in graph.cache.
+        If the normed edge already exists in graph.cache and the override parameter is False, this method will do nothing.
+
+        :param graph: tfg.Graph, the input graph.
+        :param override: Whether to override existing cached normed edge.
+        :return: None
+
+        .. deprecated:: 0.0.56
+            Use ``build_cache_for_graph`` instead.
+        """
+        warnings.warn(
+            "'APPNP.cache_normed_edge(graph, override)' is deprecated, use 'APPNP.build_cache_for_graph(graph, override)' instead",
+            DeprecationWarning)
+        return self.build_cache_for_graph(graph, override=override)
 
     def call(self, inputs, cache=None, training=None, mask=None):
         """
@@ -91,4 +109,3 @@ class APPNP(tf.keras.Model):
                      num_iterations=self.num_iterations, alpha=self.alpha,
                      dense_drop_rate=self.dense_drop_rate, edge_drop_rate=self.edge_drop_rate,
                      cache=cache, training=training)
-
